pub fn add_observer(observer: Box<dyn PreferencesObserver>)Expand description
Subscribe to notifications about changes to the global preferences for the current process.
pub fn add_observer(observer: Box<dyn PreferencesObserver>)Subscribe to notifications about changes to the global preferences for the current process.