PreferencesObserver

Trait PreferencesObserver 

pub trait PreferencesObserver: Send + Sync {
    // Provided method
    fn prefs_changed(&self, _changes: &[(&'static str, PrefValue)]) { ... }
}
A trait to be implemented by components that wish to be notified about runtime changes to the global preferences for the current process.

Provided Methods

fn prefs_changed(&self, _changes: &[(&'static str, PrefValue)])

This method is called when the global preferences have been updated. The argument to the method is an array of tuples where the first component is the name of the preference and the second component is the new value of the preference.

Implementors